let canvas1, canvas2, canvas3;

function setup() {
  // Create three canvases
  canvas1 = createCanvas(400, 400);
  canvas1.parent('sketch1');  // Attach canvas to div with id "sketch1"
  
  canvas2 = createCanvas(400, 400);
  canvas2.parent('sketch2');  // Attach canvas to div with id "sketch2"
  
  canvas3 = createCanvas(400, 400);
  canvas3.parent('sketch3');  // Attach canvas to div with id "sketch3"
  
  // Hide all canvases initially
  canvas1.hide();
  canvas2.hide();
  canvas3.hide();
  
  noLoop(); // Prevent continuous redrawing
}

function draw() {
  // Randomization: Random circles
  drawRandomization();
  
  // Contrast: Black and white grid
  drawContrast();
  
  // Repetition: Repeated circles in a grid
  drawRepetition();
}

// Function to show/hide sketches and regenerate the drawing
function showSketch(sketchNumber) {
  // Hide all canvases
  canvas1.hide();
  canvas2.hide();
  canvas3.hide();
  
  // Redraw the selected sketch and show it
  if (sketchNumber === 1) {
    canvas1.show();
    redrawRandomization();  // Redraw Randomization sketch
  } else if (sketchNumber === 2) {
    canvas2.show();
    redrawContrast();  // Redraw Contrast sketch
  } else if (sketchNumber === 3) {
    canvas3.show();
    redrawRepetition();  // Redraw Repetition sketch
  }
}

// Randomization: Draw random circles with random positions and colors
function drawRandomization() {
  // First canvas (Randomization)
  canvas1.background(255);
  
  for (let i = 0; i < 50; i++) {
    let x = random(width);
    let y = random(height);
    let size = random(10, 50);
    let col = color(random(255), random(255), random(255));
    fill(col);
    ellipse(x, y, size, size);
  }
}

// Contrast: Draw alternating black and white grid
function drawContrast() {
  // Second canvas (Contrast)
  canvas2.background(255);
  
  let gridSize = 10;
  
  for (let i = 0; i < gridSize; i++) {
    for (let j = 0; j < gridSize; j++) {
      let x = i * width / gridSize;
      let y = j * height / gridSize;
      
      // Alternate colors for contrast
      if ((i + j) % 2 == 0) {
        fill(0); // Black
      } else {
        fill(255); // White
      }
      rect(x, y, width / gridSize, height / gridSize);
    }
  }
}

// Repetition: Draw repeated circles in a grid
function drawRepetition() {
  // Third canvas (Repetition)
  canvas3.background(255);
  
  let spacing = 40;
  
  // Create a grid of repeated circles
  for (let x = 0; x < width; x += spacing) {
    for (let y = 0; y < height; y += spacing) {
      ellipse(x, y, 30, 30);
    }
  }
}

// Redraw the Randomization sketch
function redrawRandomization() {
  canvas1.background(255); // Clear the canvas
  for (let i = 0; i < 50; i++) {
    let x = random(width);
    let y = random(height);
    let size = random(10, 50);
    let col = color(random(255), random(255), random(255));
    fill(col);
    ellipse(x, y, size, size);
  }
}

// Redraw the Contrast sketch
function redrawContrast() {
  canvas2.background(255); // Clear the canvas
  let gridSize = 10;
  
  for (let i = 0; i < gridSize; i++) {
    for (let j = 0; j < gridSize; j++) {
      let x = i * width / gridSize;
      let y = j * height / gridSize;
      
      // Alternate colors for contrast
      if ((i + j) % 2 == 0) {
        fill(0); // Black
      } else {
        fill(255); // White
      }
      rect(x, y, width / gridSize, height / gridSize);
    }
  }
}

// Redraw the Repetition sketch
function redrawRepetition() {
  canvas3.background(255); // Clear the canvas
  let spacing = 40;
  
  // Create a grid of repeated circles
  for (let x = 0; x < width; x += spacing) {
    for (let y = 0; y < height; y += spacing) {
      ellipse(x, y, 30, 30);
    }
  }
}
